PalSession class

Constructors

PalSession({required String uid})
PalSession.fromJson(String source)
factory
PalSession.fromMap(Map<String, dynamic> map)
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uid ↔ String
getter/setter pair

Methods

copyWith({String? id}) → PalSession
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override